local_auth_darwin library

Classes

AuthenticationOptions
Options wrapper for LocalAuthPlatform.authenticate parameters.
AuthMessages
Abstract class for storing platform specific strings.
IOSAuthMessages
Class wrapping all authentication messages needed on iOS. Provides default values for all messages.
LocalAuthDarwin
The implementation of LocalAuthPlatform for iOS and macOS.

Enums

BiometricType
Various types of biometric authentication. Some platforms report specific biometric types, while others report only classifications like strong and weak.

Properties

iOSCancelButton String
Message shown on a button that the user can click to leave the current dialog.
no setter