localizedFallbackTitle property

String? localizedFallbackTitle
final

The localized title for the fallback button in the dialog presented to the user during authentication.

Set this to an empty string to hide the fallback button.

Implementation

final String? localizedFallbackTitle;