localizedFallbackTitle property
The localized title for the fallback button in the dialog presented to the user during authentication.
Set this to an empty string to hide the fallback button.
Implementation
final String? localizedFallbackTitle;
The localized title for the fallback button in the dialog presented to the user during authentication.
Set this to an empty string to hide the fallback button.
final String? localizedFallbackTitle;